@@ -19,7 +19,7 @@ SOGoSupportedLanguages = [ "Arabic", "Basque", "Catalan", "ChineseChina", "Chine
                            "Hungarian", "Indonesian", "Icelandic", "Italian", "Japanese",
                            "Latvian", "Lithuanian", "Macedonian", "Portuguese", "BrazilianPortuguese",
                            "NorwegianBokmal", "NorwegianNynorsk", "Polish", "Romanian", "Russian",
-                           "Serbian", "Slovak", "Slovenian", "Swedish", "TurkishTurkey", "Ukrainian" ];
+                           "Serbian", "SerbianLatin", "Slovak", "Slovenian", "Swedish", "TurkishTurkey", "Ukrainian" ];
 daysBetweenResponseList=[1,2,3,5,7,14,21,30]
 
 class HTTPPreferencesPOST (webdavlib.HTTPPOST):
