@@ -6,8 +6,8 @@
   /**
    * @ngInject
    */
-  ComponentController.$inject = ['$rootScope', '$scope', '$q', '$mdDialog', 'Calendar', 'Component', 'AddressBook', 'Alarm', 'Account', 'stateComponent'];
-  function ComponentController($rootScope, $scope, $q, $mdDialog, Calendar, Component, AddressBook, Alarm, Account, stateComponent) {
+  ComponentController.$inject = ['$rootScope', '$scope', '$q', '$mdDialog', 'Preferences', 'Calendar', 'Component', 'AddressBook', 'Account', 'stateComponent'];
+  function ComponentController($rootScope, $scope, $q, $mdDialog, Preferences, Calendar, Component, AddressBook, Account, stateComponent) {
     var vm = this, component;
 
     this.$onInit = function () {
@@ -119,7 +119,7 @@
 
       c.$reply().then(function() {
         $rootScope.$emit('calendars:list');
-        Alarm.getAlarms();
+        Preferences.getAlarms();
         $mdDialog.hide();
       });
     };
@@ -128,10 +128,11 @@
       // Retrieve master event
       component = Calendar.$get(this.component.pid).$getComponent(this.component.id);
       component.$futureComponentData.then(function() {
-        // Propagate the participant status and alarm to the master event
+        // Propagate the participant status, classification and alarm to the master event
         component.reply = vm.component.reply;
         component.delegatedTo = vm.component.delegatedTo;
         component.$hasAlarm = vm.component.$hasAlarm;
+        component.classification = vm.component.classification;
         component.alarm = vm.component.alarm;
         // Send reply to the server
         vm.reply(component);
@@ -205,24 +206,26 @@
   /**
    * @ngInject
    */
-  ComponentEditorController.$inject = ['$rootScope', '$scope', '$log', '$timeout', '$window', '$element', '$mdDialog', '$mdToast', 'sgFocus', 'User', 'CalendarSettings', 'Calendar', 'Component', 'Attendees', 'AddressBook', 'Card', 'Alarm', 'Preferences', 'stateComponent'];
-  function ComponentEditorController($rootScope, $scope, $log, $timeout, $window, $element, $mdDialog, $mdToast, focus, User, CalendarSettings, Calendar, Component, Attendees, AddressBook, Card, Alarm, Preferences, stateComponent) {
+  ComponentEditorController.$inject = ['$rootScope', '$scope', '$q', '$log', '$timeout', '$window', '$element', '$mdDialog', '$mdToast', 'sgFocus', 'User', 'CalendarSettings', 'Calendar', 'Component', 'Attendees', 'AddressBook', 'Card', 'Preferences', 'stateComponent'];
+  function ComponentEditorController($rootScope, $scope, $q, $log, $timeout, $window, $element, $mdDialog, $mdToast, focus, User, CalendarSettings, Calendar, Component, Attendees, AddressBook, Card, Preferences, stateComponent) {
     var vm = this, component, oldStartDate, oldEndDate, oldDueDate, dayStartTime, dayEndTime;
 
     this.$onInit = function () {
-      stateComponent.initAttendees();
       this.service = Calendar;
       this.component = stateComponent;
       this.categories = {};
       this.showRecurrenceEditor = this.component.$hasCustomRepeat;
       this.showAttendeesEditor = this.component.attendees && this.component.attendees.length;
-      //this.searchText = null;
-      this.attendeeConflictError = false;
-      this.attendeesEditor = {
-        days: this.component.$attendees.$days,
-        hours: getHours(),
-        containerElement: $element[0].querySelector('#freebusy')
-      };
+
+      if (this.component.type == 'appointment') {
+        this.component.initAttendees();
+        this.attendeeConflictError = false;
+        this.attendeesEditor = {
+          days: this.component.$attendees.$days,
+          hours: getHours(),
+          containerElement: $element[0].querySelector('#freebusy')
+        };
+      }
 
       if (this.component.start) {
         oldStartDate = new Date(this.component.start.getTime());
@@ -278,19 +281,19 @@
     this.changeCalendar = function () {
       var updateRequired = (this.component.attendees && this.component.attendees.length > 0);
       if (updateRequired)
-        this.component.initOrganizer(Calendar.$get(this.component.destinationCalendar));
+        this.component.$attendees.initOrganizer(Calendar.$get(this.component.destinationCalendar));
     };
 
     // Autocomplete cards for attendees
     this.cardFilter = function ($query) {
-      AddressBook.$filterAll($query);
-      return AddressBook.$cards;
+      return AddressBook.$filterAll($query);
     };
 
     this.addAttendee = function (card, partial) {
       var initOrganizer = (!this.component.attendees || this.component.attendees.length === 0),
           destinationCalendar = Calendar.$get(this.component.destinationCalendar),
-          options = initOrganizer? { organizerCalendar: destinationCalendar } : {};
+          options = initOrganizer? { organizerCalendar: destinationCalendar } : {},
+          promises = [];
       var emailRE = /([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?)/i,
           i, address;
       if (partial) options.partial = partial;
@@ -301,7 +304,21 @@
             name = str.replace(new RegExp(" *<?" + email + ">? *"), '');
         vm.showAttendeesEditor |= initOrganizer;
         vm.searchText = '';
-        return new Card({ c_cn: _.trim(name, ' "'), emails: [{ value: email }] });
+        return vm.cardFilter(email).then(function (cards) {
+          if (cards.length) {
+            return cards[0];
+          } else {
+            return new Card({ c_cn: _.trim(name, ' "'), emails: [{ value: email }] });
+          }
+        }).catch(function (err) {
+          // Server error
+          return new Card({ c_cn: _.trim(name, ' "'), emails: [{ value: email }] });
+        });
+      }
+
+      function addCard(newCard) {
+        if (!vm.component.$attendees.hasAttendee(newCard))
+          return vm.component.$attendees.add(newCard, options);
       }
 
       if (angular.isString(card)) {
@@ -317,22 +334,27 @@
                card.charCodeAt(i) == 44 ||   // ,
                card.charCodeAt(i) == 59) &&  // ;
               emailRE.test(address)) {
-            this.component.$attendees.add(createCard(address), options);
+            promises.push(createCard(address).then(addCard));
             address = '';
           }
           else {
             address += card.charAt(i);
           }
         }
-        if (address)
-          this.component.$attendees.add(createCard(address), options);
+        if (address && emailRE.test(address)) {
+          promises.push(createCard(address).then(addCard));
+        }
       }
-      else {
-        this.component.$attendees.add(card, options);
+      else if (angular.isDefined(card)) {
+        if (!this.component.$attendees.hasAttendee(card))
+          promises.push(this.component.$attendees.add(card, options));
         this.showAttendeesEditor |= initOrganizer;
       }
 
-      $timeout(scrollToStart);
+      if (_.has(this.component, '$attendees'))
+        $timeout(scrollToStart);
+
+      return $q.all(promises);
     };
 
     function scrollToStart() {
@@ -384,7 +406,11 @@
     };
 
     function findSlot(direction) {
+      vm.adjustStartTime();
+      vm.adjustEndTime();
       vm.component.$attendees.findSlot(direction).then(function () {
+        vm.startTime = new Date(vm.component.start.getTime());
+        vm.endTime = new Date(vm.component.end.getTime());
       }).catch(function (err) {
         vm.component.start = new Date(vm.component.start.getTime() + 1); // trigger update in sgFreeBusy
         $timeout(scrollToStart);
@@ -443,21 +469,25 @@
     };
 
     this.save = function (form, options) {
+      this.adjustStartTime();
+      this.adjustEndTime();
       this.changeAlarmRelation(form);
-      if (form.$valid) {
-        this.component.$save(options)
-          .then(function(data) {
-            $rootScope.$emit('calendars:list');
-            Alarm.getAlarms();
-            $mdDialog.hide();
-          }, function(response) {
-            if (response.status == CalendarSettings.ConflictHTTPErrorCode &&
-                _.isObject(response.data.message))
-              vm.attendeeConflictError = response.data.message;
-            else
-              vm.edit(form);
-          });
-      }
+      this.addAttendee(this.searchText).then(function () {
+        if (form.$valid) {
+          vm.component.$save(options)
+            .then(function(data) {
+              $rootScope.$emit('calendars:list');
+              Preferences.getAlarms();
+              $mdDialog.hide();
+            }, function(response) {
+              if (response.status == CalendarSettings.ConflictHTTPErrorCode &&
+                  _.isObject(response.data.message))
+                vm.attendeeConflictError = response.data.message;
+              else
+                vm.edit(form);
+            });
+        }
+      });
     };
 
     this.reset = function (form) {
@@ -567,12 +597,17 @@
     this.adjustEndTime = function () {
       var delta;
       if (this.component.end && this.endTime) {
-        // Update the component start date
+        // Update the component end date
         this.component.end.setHours(this.endTime.getHours());
         this.component.end.setMinutes(this.endTime.getMinutes());
         // The end date must be after the start date
         delta = oldEndDate.valueOf() - this.component.end.valueOf();
         if (delta !== 0) {
+          if (this.startTime) {
+            // Update the component start date
+            this.component.start.setHours(this.startTime.getHours());
+            this.component.start.setMinutes(this.startTime.getMinutes());
+          }
           delta = this.component.start.minutesTo(this.component.end);
           if (delta < 0) {
             this.component.end = new Date(oldEndDate.getTime());
@@ -596,9 +631,11 @@
     };
 
     function updateFreeBusy() {
-      vm.component.$attendees.updateFreeBusyCoverage();
-      vm.component.$attendees.updateFreeBusy();
-      $timeout(scrollToStart);
+      if (_.has(vm.component, '$attendees')) {
+        vm.component.$attendees.updateFreeBusyCoverage();
+        vm.component.$attendees.updateFreeBusy();
+        $timeout(scrollToStart);
+      }
     }
   }
 
